@@ -13,6 +13,7 @@ module Database.Persist.Types.Base
     , PersistValue(..)
     , fromPersistValueText
     , LiteralType(..)
+    , SourceSpan(..)
     ) where
 
 import Control.Exception (Exception)
@@ -38,6 +39,7 @@ import Instances.TH.Lift ()
 
 import Database.Persist.Names
 import Database.Persist.PersistValue
+import Database.Persist.Types.SourceSpan (SourceSpan(..))
 
 -- | A 'Checkmark' should be used as a field type whenever a
 -- uniqueness constraint should guarantee that a certain kind of
@@ -155,6 +157,14 @@ data EntityDef = EntityDef
     -- ^ Optional comments on the entity.
     --
     -- @since 2.10.0
+    , entitySpan :: !(Maybe SourceSpan)
+    -- ^ Source code span occupied by this entity. May be absent if it is not
+    -- known.
+    --
+    -- Note that until a refactor is completed, these cover the entire
+    -- persistent parser input rather than the particular entity in question.
+    --
+    -- @since 2.15.0.0
     }
     deriving (Show, Eq, Read, Ord, Lift)
 
@@ -213,7 +223,7 @@ keyAndEntityFields ent =
 --
 -- For fields on the Haskell type use 'keyAndEntityFieldsDatabase'
 --
--- @since 2.14.6.0
+-- @since 2.15.1.0
 keyAndEntityFieldsDatabase :: EntityDef -> NonEmpty FieldDef
 keyAndEntityFieldsDatabase ent =
     keyWithFields (entityId ent) fields
