@@ -14,6 +14,7 @@ import Language.Haskell.TH.Syntax
 
 import Database.Persist.Quasi
 import Database.Persist.TH
+import Database.Persist.TH.Internal
 import Models
 
 main :: IO ()
@@ -131,8 +132,11 @@ instance NFData DerivStrategy where
 instance NFData DerivClause where
 #endif
 
-#if MIN_VERSION_template_haskell(2,22,0)
+#if MIN_VERSION_template_haskell(2,21,0)
 instance NFData BndrVis where
+#endif
+
+#if MIN_VERSION_template_haskell(2,22,0)
 instance NFData NamespaceSpecifier where
 #endif
 
