@@ -21,7 +21,11 @@ import TemplateTestImports
 
 mkPersist sqlSettings {mpsFieldLabelModifier = const id} [persistLowerCase|
 User
+    ident Text
     name Text
+    Primary ident
+    team TeamId
+    type Text
 
 Team
     name Text
@@ -32,9 +36,9 @@ spec = it "compiles" True
 
 #else
 
-spec :: Spec 
+spec :: Spec
 spec = do
     it "only works with GHC 9.2 or greater" $ do
-        pendingWith "only works with GHC 9.2 or greater"    
+        pendingWith "only works with GHC 9.2 or greater"
 
-#endif
\ No newline at end of file
+#endif
